
clear;
clc;

%warning off
s = RandStream('mt19937ar');
RandStream.setGlobalStream(s);


Y=xlsread('Data.xlsx',1,'B2:F115');

startdate=1900;
enddate=2013;

m1rsy=Y(:,4);   %M1RS/GDP ratio
r=Y(:,5);       %Interest rate

year=(startdate:1:enddate)';


%I(1) Processes

y=log(m1rsy);
zb=log(r);		%[] if empty; I(1) non-trending process subject to breaks
zb_t=[];        %[] if empty; I(1) trending process subject to breaks
zf=[];          %[] if empty; I(1) non-trending process fixed
zf_t=[];        %[] if empty; I(1) trending process fixed
xb=[];          %[] if empty; I(0) process subject to breaks
xf=[];          %[] if empty; I(0) process fixed


% Deterministic processes

ncb=1;                   %broken constant
ncf=0;                   %fixed constant
						 %ncb=ncf=0 => no constant

ntb=0;                   %broken trend
ntf=0;                   %fixed trend
						 %ntb=ntf=0 => no trend


ll=4;                    %number of leads and lags used for DOLS estimation
eps1=.15;                %trimming for segments. There are five options: eps1 = .05, .10, .15, .20 or .25.
                         %for each option, the maximal value of m above is: 10 for eps1 = .05;
                         %8 for eps1 = .10, 5 for eps1 = .15, 3 for eps1 = .20 and 2 for eps1 = .25.@
m=5;                     %maximum number of breaks




%% --------------------------------------------------------------------------- 


x=0;
bigt=size(y,1);            %set effective sample size

cb=[];
cf=[];
tb=[];
tf=[];

if ncf==1 
   cf=ones(bigt,1);      
end
if ncb==1 
   cb=ones(bigt,1);      
end
if ntf==1 
   tf=(1:1:bigt)'/bigt;
end
if ntb==1 
   tb=(1:1:bigt)'/bigt;
end

% if LL>0 Build DOLS regression
zdols=[];
if ll>0
   z=[zb zb_t zf zf_t];
   dz=[zeros(1,size(z,2));z(2:end,:)-z(1:end-1,:)];
   zdols=dz;
   for lf=1:1:ll
       zdols=[zdols [zeros(lf,size(dz,2));dz(1:end-lf,:)]];  %lags
       zdols=[zdols [dz(1+lf:end,:);zeros(lf,size(dz,2))]];  %leads   
   end
end


z_b=[zb zb_t];            %I(1) variables subjects to breaks
z_f=[zf zf_t];            %I(1) variables fixed
x_b=xb;                   %I(0) variables subjects to breaks
x_f=[xf zdols];           %I(0) variables fixed
d_b=[cb tb];
d_f=[cf tf];

qb=size(z_b,2);           %number of I(1) regressors whose coefficients are allowed to change
qf=size(z_f,2);           %number of I(1) regressors whose coefficients are NOT allowed to change
pb=size(x_b,2);           %number of I(0) regressors whose coefficients are allowed to change
pf=size(x_f,2);           %number of I(0) regressors whose coefficients are NOT allowed to change


b=qb+pb+ncb+ntb;          %number of TOTAL regressors (including deterministics) whose coefficients are allowed to change
f=qf+pf+ncf+ntf;          %number of regressors whose coefficients are NOT allowed to change

h=round(eps1*(bigt-(ll*2+1))); %minimal length of a segment (h >= q)@


% the following are options if p > 0.
fixb=0;                   %set to 1 if use fixed initial values for beta
betaini={0,0,0};          %if fixb=1, load the initial value of beta
maxi=20;                  %maximum number of iterations for the nonlinear procedure to obtain global minimizers
eps=0.001;                %criterion for the convergence
dotesting=1;               


%% --------------------------------------------------------------------------- 
% Break dates selected with the Eviews program "analysis_usa_ll.prg"

                        
break_dates=NaN(m,m);

if eps1==.15
break_dates(1,1)=find(year==1936)-1;
break_dates(2,1:2)=[find(year==1945)-1, find(year==1976)-1];
break_dates(3,1:3)=[find(year==1945)-1, find(year==1961)-1, find(year==1976)-1];
break_dates(4,1:4)=[find(year==1923)-1, find(year==1945)-1, find(year==1961)-1, find(year==1976)-1];
break_dates(5,1:5)=[find(year==1923)-1, find(year==1945)-1, find(year==1961)-1, find(year==1976)-1, find(year==1991)-1];
end

if eps1==.20
break_dates(1,1)=find(year==1936)-1;
break_dates(2,1:2)=[find(year==1945)-1, find(year==1976)-1];
break_dates(3,1:3)=[find(year==1930)-1, find(year==1951)-1, find(year==1976)-1];
end


[break_dates,ftest,udmax,bic,lwz]=break_tests3(break_dates,bigt,y,z_b,z_f,d_b,d_f,m,h,eps1,ll,b,f,qb,qf,pb,pf,dotesting,fixb,eps,maxi,betaini,year);


